@@ -238,7 +238,7 @@ def line_triangle_intersect(
     p2: np.ndarray,
     p3: np.ndarray,
 ) -> bool:
-    """Check if line intersects triangle, return boolean
+    """Check if line intersects triangle, return boolean.
 
     NOTE: Line does not mean Ray!! Ray goes to infinite. Line is finite.
 
@@ -262,3 +262,27 @@ def line_triangle_intersect(
     d3 = distance(start, end)
     diff = d3 - (d1 + d2)
     return diff < DIFF and diff > -DIFF
+
+
+def point_inside_polygon(x: float, y: float, poly: List[Tuple[float, float]]) -> bool:
+    """Check if a given point is inside the given polygon in 2D.
+
+    This work is copied from Patrick Jordan's work;
+    http://web.archive.org/web/20200216234902/http://www.ariel.com.au/a/python-point-int-poly.html
+    """
+    n = len(poly)
+    inside = False
+
+    p1x, p1y = poly[0]
+    for i in range(n + 1):
+        p2x, p2y = poly[i % n]
+        if y > min(p1y, p2y):
+            if y <= max(p1y, p2y):
+                if x <= max(p1x, p2x):
+                    if p1y != p2y:
+                        xinters = (y - p1y) * (p2x - p1x) / (p2y - p1y) + p1x
+                    if p1x == p2x or x <= xinters:
+                        inside = not inside
+        p1x, p1y = p2x, p2y
+
+    return inside
