@@ -179,7 +179,7 @@ class Window(WindowElement):
         self.add_child(
             "title",
             Text(
-                position=[0, 0, 0],
+                position=[10, 0, 0],
                 size=[self.size[0], 20],
                 label=self.title,
                 # bgcolor=self.theme.title_background_color,
@@ -333,7 +333,7 @@ class Button(Panel):
             crop[3] = int(text_size[1] - crop[1])
             text_size = (text_size[0], self.size[1])
         self.text.crop = crop
-        self.text.size = [int(text_size[0]), int(text_size[1] + 4)]
+        self.text.size = [int(text_size[0]), int(text_size[1])]
 
     @property
     def label(self) -> str:
