@@ -1,10 +1,9 @@
-from payton.math.matrix import Matrix
 from typing import Any, Dict, List, Optional
 
-import numpy as np  # type: ignore
+import numpy as np
 
-from payton.math.vector import Vector3D
 from payton.math.functions import cubemap_projection_matrices
+from payton.math.vector import Vector3D
 
 
 class Light:
@@ -56,7 +55,7 @@ class Light:
         }
 
     @property
-    def shadow_matrices(self) -> List[Matrix]:
+    def shadow_matrices(self) -> List[np.ndarray]:
         """Return the shadow casting cubemap projection matrices for the light"""
         if len(self._shadow_matrices) > 0:
             return self._shadow_matrices
@@ -69,7 +68,7 @@ class Light:
         return self._shadow_far_plane
 
     @shadow_far_plane.setter
-    def shadow_far_plane(self, distance: float):
+    def shadow_far_plane(self, distance: float) -> None:
         """Set the furthest distance that the light can cast shadows
 
         Keyword arguments:
