@@ -1,3 +1,3 @@
-class Receiver(object):
+class Receiver:
     def __str__(self) -> str:
         return "Scene"
